@@ -21,6 +21,7 @@
 package org.videolan.libvlc;
 
 import android.net.Uri;
+import android.support.annotation.Nullable;
 
 import org.videolan.libvlc.util.AndroidUtil;
 import org.videolan.libvlc.util.HWDecoderUtil;
@@ -39,7 +40,6 @@ public class Media extends VLCObject<Media.Event> {
         //public static final int Freed                      = 4;
         public static final int StateChanged = 5;
         public static final int SubItemTreeAdded = 6;
-        public static final int ParsedStatus = 7;
 
         protected Event(int type) {
             super(type);
@@ -51,6 +51,14 @@ public class Media extends VLCObject<Media.Event> {
         public int getMetaId() {
             return (int) arg1;
         }
+
+        /**
+         * Get the ParsedStatus in case of {@link Event#ParsedChanged} event
+         * @return {@link Media.ParsedStatus}
+         */
+        public int getParsedStatus() {
+            return (int) arg1;
+        }
     }
 
     public interface EventListener extends VLCEvent.Listener<Media.Event> {}
@@ -105,7 +113,7 @@ public class Media extends VLCObject<Media.Event> {
     public static class State {
         public static final int NothingSpecial = 0;
         public static final int Opening = 1;
-        public static final int Buffering = 2;
+        /* deprecated public static final int Buffering = 2; */
         public static final int Playing = 3;
         public static final int Paused = 4;
         public static final int Stopped = 5;
@@ -125,6 +133,15 @@ public class Media extends VLCObject<Media.Event> {
         public static final int DoInteract   = 0x08;
     }
 
+    /*
+     * see libvlc_media_parsed_status_t
+     */
+    public static class ParsedStatus {
+        public static final int Skipped = 1;
+        public static final int Failed = 2;
+        public static final int Done = 3;
+    }
+
     /**
      * see libvlc_media_track_t
      */
@@ -258,6 +275,33 @@ public class Media extends VLCObject<Media.Event> {
                 level, bitrate, language, description);
     }
 
+    /**
+     * see libvlc_media_slave_t
+     */
+    public static class Slave {
+        public static class Type {
+            public static final int Subtitle = 0;
+            public static final int Audio = 1;
+        }
+
+        /** @see Type */
+        public final int type;
+        /** From 0 (low priority) to 4 (high priority) */
+        public final int priority;
+        public final String uri;
+
+        public Slave(int type, int priority, String uri) {
+            this.type = type;
+            this.priority = priority;
+            this.uri = uri;
+        }
+    }
+
+    @SuppressWarnings("unused") /* Used from JNI */
+    private static Slave createSlaveFromNative(int type, int priority, String uri) {
+        return new Slave(type, priority, uri);
+    }
+
     private static final int PARSE_STATUS_INIT = 0x00;
     private static final int PARSE_STATUS_PARSING = 0x01;
     private static final int PARSE_STATUS_PARSED = 0x02;
@@ -386,9 +430,6 @@ public class Media extends VLCObject<Media.Event> {
             mDuration = -1;
             break;
         case Event.ParsedChanged:
-            postParse();
-            break;
-        case Event.ParsedStatus:
             postParse();
             return new Event(eventType, arg1);
         case Event.StateChanged:
@@ -691,6 +732,39 @@ public class Media extends VLCObject<Media.Event> {
         nativeAddOption(option);
     }
 
+
+    /**
+     * Add a slave to the current media.
+     *
+     * A slave is an external input source that may contains an additional subtitle
+     * track (like a .srt) or an additional audio track (like a .ac3).
+     *
+     * This function must be called before the media is parsed (via {@link #parseAsync(int)}} or
+     * before the media is played (via {@link MediaPlayer#play()})
+     */
+    public void addSlave(Slave slave) {
+        nativeAddSlave(slave.type, slave.priority, slave.uri);
+    }
+
+    /**
+     * Clear all slaves previously added by {@link #addSlave(Slave)} or internally.
+     */
+    public void clearSlaves() {
+        nativeClearSlaves();
+    }
+
+    /**
+     * Get a media's slave list
+     *
+     * The list will contain slaves parsed by VLC or previously added by
+     * {@link #addSlave(Slave)}. The typical use case of this function is to save
+     * a list of slave in a database for a later use.
+     */
+    @Nullable
+    public Slave[] getSlaves() {
+        return nativeGetSlaves();
+    }
+
     @Override
     protected void onReleaseNative() {
         if (mSubItems != null)
@@ -713,4 +787,7 @@ public class Media extends VLCObject<Media.Event> {
     private native long nativeGetDuration();
     private native int nativeGetType();
     private native void nativeAddOption(String option);
+    private native void nativeAddSlave(int type, int priority, String uri);
+    private native void nativeClearSlaves();
+    private native Slave[] nativeGetSlaves();
 }
\ No newline at end of file
