@@ -29,7 +29,7 @@ public class MediaPlayer extends VLCObject<MediaPlayer.Event> {
         public static final int MediaChanged        = 0x100;
         //public static final int NothingSpecial      = 0x101;
         public static final int Opening             = 0x102;
-        //public static final int Buffering           = 0x103;
+        public static final int Buffering           = 0x103;
         public static final int Playing             = 0x104;
         public static final int Paused              = 0x105;
         public static final int Stopped             = 0x106;
@@ -78,6 +78,9 @@ public class MediaPlayer extends VLCObject<MediaPlayer.Event> {
         public boolean getSeekable() {
             return arg1 != 0;
         }
+        public float getBuffering() {
+            return arg2;
+        }
     }
 
     public interface EventListener extends VLCEvent.Listener<MediaPlayer.Event> {}
@@ -358,17 +361,6 @@ public class MediaPlayer extends VLCObject<MediaPlayer.Event> {
             }
             if (disableVideo)
                 setVideoTrackEnabled(false);
-            synchronized (MediaPlayer.this) {
-                /* Wait for Vout destruction (mVoutCount = 0) in order to be sure that the surface is not
-                 * used after leaving this callback. This shouldn't be needed when using MediaCodec or
-                 * AndroidWindow (i.e. after Android 2.3) since the surface is ref-counted */
-                while (mVoutCount > 0) {
-                    try {
-                        MediaPlayer.this.wait();
-                    } catch (InterruptedException ignored) {
-                    }
-                }
-            }
         }
     });
 
@@ -822,6 +814,8 @@ public class MediaPlayer extends VLCObject<MediaPlayer.Event> {
                 mVoutCount = 0;
                 notify();
             case Event.Opening:
+            case Event.Buffering:
+                return new Event(eventType, arg2);
             case Event.Playing:
             case Event.Paused:
                 return new Event(eventType);
