@@ -66,6 +66,7 @@ import org.videolan.libvlc.MediaList;
 import org.videolan.libvlc.MediaPlayer;
 import org.videolan.libvlc.util.AndroidUtil;
 import org.videolan.vlc.gui.AudioPlayerContainerActivity;
+import org.videolan.vlc.gui.browser.NetworkBrowserFragment;
 import org.videolan.vlc.gui.helpers.AudioUtil;
 import org.videolan.vlc.gui.preferences.PreferencesActivity;
 import org.videolan.vlc.gui.preferences.PreferencesFragment;
@@ -352,7 +353,7 @@ public class PlaybackService extends Service implements IVLCVout.Callback {
     private OnAudioFocusChangeListener createOnAudioFocusChangeListener() {
         return new OnAudioFocusChangeListener() {
             private boolean mLossTransient = false;
-            private boolean mLossTransientCanDuck = false;
+            private int mLossTransientVolume = -1;
             private boolean wasPlaying = false;
 
             @Override
@@ -380,15 +381,15 @@ public class PlaybackService extends Service implements IVLCVout.Callback {
                         // Lower the volume
                         if (mMediaPlayer.isPlaying()) {
                             mMediaPlayer.setVolume(36);
-                            mLossTransientCanDuck = true;
+                            mLossTransientVolume = mMediaPlayer.getVolume();
                         }
                         break;
                     case AudioManager.AUDIOFOCUS_GAIN:
-                        Log.i(TAG, "AUDIOFOCUS_GAIN: " + mLossTransientCanDuck + ", " + mLossTransient);
+                        Log.i(TAG, "AUDIOFOCUS_GAIN: " + mLossTransientVolume + ", " + mLossTransient);
                         // Resume playback
-                        if (mLossTransientCanDuck) {
-                            mMediaPlayer.setVolume(100);
-                            mLossTransientCanDuck = false;
+                        if (mLossTransientVolume != -1) {
+                            mMediaPlayer.setVolume(mLossTransientVolume);
+                            mLossTransientVolume = -1;
                         } else if (mLossTransient) {
                             if (wasPlaying)
                                 mMediaPlayer.play();
@@ -1707,6 +1708,18 @@ public class PlaybackService extends Service implements IVLCVout.Callback {
         mPausable = mSeekable = true;
         final Media media = new Media(VLCInstance.get(), mw.getUri());
         VLCOptions.setMediaOptions(media, this, flags | mw.getFlags());
+
+        if (mw.getSlaves() != null) {
+            for (Media.Slave slave : mw.getSlaves())
+                media.addSlave(slave);
+            VLCApplication.runBackground(new Runnable() {
+                @Override
+                public void run() {
+                    MediaDatabase.getInstance().saveSlaves(mw);
+                }
+            });
+        }
+
         media.setEventListener(mMediaListener);
         mMediaPlayer.setMedia(media);
         media.release();
