@@ -20,16 +20,6 @@
 
 package org.videolan.vlc.media;
 
-import java.io.ByteArrayOutputStream;
-import java.io.File;
-import java.text.SimpleDateFormat;
-import java.util.ArrayList;
-import java.util.Collection;
-import java.util.Date;
-import java.util.HashSet;
-import java.util.List;
-import java.util.Locale;
-
 import android.content.ContentValues;
 import android.content.Context;
 import android.database.Cursor;
@@ -45,9 +35,20 @@ import android.support.v4.util.ArrayMap;
 import android.text.TextUtils;
 import android.util.Log;
 
+import org.videolan.libvlc.Media;
 import org.videolan.libvlc.util.AndroidUtil;
 import org.videolan.vlc.VLCApplication;
 
+import java.io.ByteArrayOutputStream;
+import java.io.File;
+import java.text.SimpleDateFormat;
+import java.util.ArrayList;
+import java.util.Collection;
+import java.util.Date;
+import java.util.HashSet;
+import java.util.List;
+import java.util.Locale;
+
 public class MediaDatabase {
     public final static String TAG = "VLC/MediaDatabase";
 
@@ -55,7 +56,7 @@ public class MediaDatabase {
 
     private SQLiteDatabase mDb;
     private static final String DB_NAME = "vlc_database";
-    private static final int DB_VERSION = 24;
+    private static final int DB_VERSION = 26;
     private static final int CHUNK_SIZE = 50;
 
     private static final String DIR_TABLE_NAME = "directories_table";
@@ -100,6 +101,16 @@ public class MediaDatabase {
     private static final String MRL_URI = "uri";
     private static final String MRL_TABLE_SIZE = "100";
 
+    private static final String EXTERNAL_SUBTITLES_TABLE_NAME = "external_subtitles_table";
+    private static final String EXTERNAL_SUBTITLES_MEDIA_NAME = "media_name";
+    private static final String EXTERNAL_SUBTITLES_URI = "uri";
+
+    private static final String SLAVES_TABLE_NAME = "SLAVES_table";
+    private static final String SLAVES_MEDIA_PATH = "slave_media_mrl";
+    private static final String SLAVES_TYPE = "slave_type";
+    private static final String SLAVES_PRIORITY = "slave_priority";
+    private static final String SLAVES_URI = "slave_uri";
+
     private static final String HISTORY_TABLE_NAME = "history_table";
     private static final String HISTORY_DATE = MEDIA_LAST_MODIFIED;
     private static final String HISTORY_TITLE = MEDIA_TITLE;
@@ -337,6 +348,26 @@ public class MediaDatabase {
             }
         }
 
+        private void createExtSubsTableQuery(SQLiteDatabase db) {
+            String createMrlTableQuery = "CREATE TABLE IF NOT EXISTS " +
+                    EXTERNAL_SUBTITLES_TABLE_NAME + " (" +
+                    EXTERNAL_SUBTITLES_URI + " TEXT PRIMARY KEY NOT NULL, " +
+                    EXTERNAL_SUBTITLES_MEDIA_NAME + " TEXT NOT NULL" +
+                    ");";
+            db.execSQL(createMrlTableQuery);
+        }
+
+        private void createSlavesTableQuery(SQLiteDatabase db) {
+            String createMrlTableQuery = "CREATE TABLE IF NOT EXISTS " +
+                    SLAVES_TABLE_NAME + " (" +
+                    SLAVES_MEDIA_PATH + " TEXT PRIMARY KEY NOT NULL, " +
+                    SLAVES_TYPE + " INTEGER NOT NULL, " +
+                    SLAVES_PRIORITY + " INTEGER, " +
+                    SLAVES_URI + " TEXT NOT NULL" +
+                    ");";
+            db.execSQL(createMrlTableQuery);
+        }
+
         @Override
         public void onCreate(SQLiteDatabase db) {
 
@@ -369,6 +400,10 @@ public class MediaDatabase {
                 createNetworkFavTableQuery(db);
 
                 createHistoryTableQuery(db);
+
+                createExtSubsTableQuery(db);
+
+                createSlavesTableQuery(db);
             }
         }
 
@@ -407,6 +442,13 @@ public class MediaDatabase {
                         case 24:
                             dropNetworkFavTableQuery(db);
                             createNetworkFavTableQuery(db);
+                            break;
+                        case 25:
+                            createExtSubsTableQuery(db);
+                            break;
+                        case 26:
+                            createSlavesTableQuery(db);
+                            break;
                         default:
                             break;
                     }
@@ -1252,9 +1294,96 @@ public class MediaDatabase {
     public synchronized void clearNetworkFavTable() {
         mDb.delete(NETWORK_FAV_TABLE_NAME, null, null);
     }
+
+    /**
+     * External subtitles management
+     */
+
+    public synchronized void saveSubtitle(String path, String mediaName) {
+        ContentValues values = new ContentValues();
+        values.put(EXTERNAL_SUBTITLES_URI, path);
+        values.put(EXTERNAL_SUBTITLES_MEDIA_NAME, mediaName);
+        mDb.replace(EXTERNAL_SUBTITLES_TABLE_NAME, null, values);
+    }
+
+    public synchronized ArrayList<String> getSubtitles(String mediaName) {
+        Cursor cursor = mDb.query(EXTERNAL_SUBTITLES_TABLE_NAME,
+                new String[] {EXTERNAL_SUBTITLES_MEDIA_NAME, EXTERNAL_SUBTITLES_URI },
+                EXTERNAL_SUBTITLES_MEDIA_NAME + "=?",
+                new String[] { mediaName },
+                null, null, null);
+        ArrayList<String> list = new ArrayList<>(cursor.getCount());
+        if (cursor != null) {
+            while (cursor.moveToNext()) {
+                String url = cursor.getString(1);
+                if (!TextUtils.isEmpty(url)) {
+                    String fileUrl = Uri.decode(url);
+                    if (new File(fileUrl).exists())
+                        list.add(fileUrl);
+                    else
+                        deleteSubtitle(url);
+                }
+            }
+            cursor.close();
+        }
+        return list;
+    }
+
+    public synchronized void deleteSubtitle(String path) {
+        mDb.delete(EXTERNAL_SUBTITLES_TABLE_NAME, EXTERNAL_SUBTITLES_URI + "=?", new String[] { path });
+    }
+
+    public synchronized void clearExternalSubtitlesTable() {
+        mDb.delete(EXTERNAL_SUBTITLES_TABLE_NAME, null, null);
+    }
+
+    /**
+     * slaves management
+     */
+
+    public synchronized void saveSlaves(MediaWrapper mw) {
+        for (Media.Slave slave : mw.getSlaves()) {
+            ContentValues values = new ContentValues();
+            values.put(SLAVES_MEDIA_PATH, mw.getLocation());
+            values.put(SLAVES_TYPE, slave.type);
+            values.put(SLAVES_PRIORITY, slave.priority);
+            values.put(SLAVES_URI, slave.uri);
+            mDb.replace(SLAVES_TABLE_NAME, null, values);
+        }
+    }
+
+    public synchronized ArrayList<Media.Slave> getSlaves(String mrl) {
+        Cursor cursor = mDb.query(SLAVES_TABLE_NAME,
+                new String[] {SLAVES_MEDIA_PATH, SLAVES_TYPE, SLAVES_PRIORITY, SLAVES_URI },
+                SLAVES_MEDIA_PATH + "=?",
+                new String[] { mrl },
+                null, null, null);
+        ArrayList<Media.Slave> list = new ArrayList<>(cursor.getCount());
+        if (cursor != null) {
+            while (cursor.moveToNext()) {
+                String uri = cursor.getString(3);
+                if (!TextUtils.isEmpty(uri)) {
+                    uri = Uri.decode(uri);
+                list.add(new Media.Slave(cursor.getInt(1), cursor.getInt(2), uri));
+                }
+            }
+            cursor.close();
+        }
+        return list;
+    }
+
+    public synchronized void deleteSlaves(String mrl) {
+        mDb.delete(SLAVES_TABLE_NAME, SLAVES_MEDIA_PATH + "=?", new String[] { mrl });
+    }
+
+    public synchronized void clearSlavesTable() {
+        mDb.delete(SLAVES_TABLE_NAME, null, null);
+    }
+
     /**
      * Empty the database for debugging purposes
      */
+
     public synchronized void emptyDatabase() {
         mDb.delete(MEDIA_TABLE_NAME, null, null);
     }
